Index: src/org/openstreetmap/josm/actions/downloadtasks/DownloadTaskList.java
===================================================================
--- src/org/openstreetmap/josm/actions/downloadtasks/DownloadTaskList.java	(revision 16760)
+++ src/org/openstreetmap/josm/actions/downloadtasks/DownloadTaskList.java	(working copy)
@@ -265,10 +265,9 @@
                                 + tr("The following errors occurred during mass download: {0}",
                                         Utils.joinAsHtmlUnorderedList(items)) + "</html>",
                                 tr("Errors during download"), JOptionPane.ERROR_MESSAGE);
+                        return;
                     }
                 });
-
-                return;
             }
 
             // FIXME: this is a hack. We assume that the user canceled the whole download if at

Index: src/org/openstreetmap/josm/actions/UpdateDataAction.java
===================================================================
--- src/org/openstreetmap/josm/actions/UpdateDataAction.java	(revision 16760)
+++ src/org/openstreetmap/josm/actions/UpdateDataAction.java	(working copy)
@@ -12,6 +12,7 @@
 import java.util.stream.Collectors;
 
 import org.openstreetmap.josm.actions.downloadtasks.DownloadTaskList;
+import org.openstreetmap.josm.data.osm.OsmPrimitive;
 import org.openstreetmap.josm.gui.layer.OsmDataLayer;
 import org.openstreetmap.josm.gui.progress.swing.PleaseWaitProgressMonitor;
 import org.openstreetmap.josm.io.NetworkManager;
@@ -85,8 +86,9 @@
                 .collect(Collectors.toList());
 
         if (areasToDownload.isEmpty()) {
-            // no bounds defined in the dataset? we update all primitives in the data set using a series of multi fetch requests
-            UpdateSelectionAction.updatePrimitives(editLayer.data.allPrimitives());
+            // no bounds defined in the dataset? we update all selectable primitives in the data set using a series of multi fetch requests
+            UpdateSelectionAction.updatePrimitives(editLayer.data.allPrimitives().stream()
+                    .filter(OsmPrimitive::isSelectable).collect(Collectors.toList()));
         } else {
             // bounds defined? => use the bbox downloader
             final PleaseWaitProgressMonitor monitor = new PleaseWaitProgressMonitor(tr("Download data"));